Sviluppo — SoL 4, manuale utente

# Sviluppo

Lo sviluppo di SoL avviene in un repository git ospitato da GitLab, che viene automaticamente sincronizzato su Bitbucket.

Puoi visitare la pagina con l'attività per vedere cosa è stato fatto di recente.

Se sei uno sviluppatore, sei incoraggiato a creare un fork per adattare e migliorare SoL e sarò più che contento di integrare le modifiche che potrai contribuire.

In alternativa puoi tradurlo in un'altra lingua, usando il servizio online di Weblate.

C'è anche una documentazione tecnica estratta automaticamente dai sorgenti.